# caso [![Build Status](https://travis-ci.org/IFCA/caso.png)](https://travis-ci.org/IFCA/caso)

cASO is an OpenStack Accounting extractor.

* Free software: Apache license
* Source: https://github.com/IFCA/caso
* Bugs: https://github.com/IFCA/caso/issues

Documentation (the source is in ``doc/source/``) is online at
[caso documentation](https://caso.readthedocs.org/en/latest/).

[Build Status]: https://travis-ci.org/IFCA/caso
[BS img]: https://travis-ci.org/IFCA/caso.png
